import{N as l}from"./Navbar-BX0Gfh7A.js";import{B as f}from"./BaseLayout-F1PR4BH7.js";import{C as b}from"./ContentLayout-CEtL_ALE.js";import{e as g,an as _,b as r,ab as v,f as a,h as i,w as n,m as c,g as y}from"./jwt-decode.esm-pqcXkgNc.js";import{_ as w}from"./BillingAlert.vue_vue_type_script_setup_true_lang-4D3ssWvZ.js";import{u as z}from"./projectsStore-DCJJAbRW.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-BmbSCZr1.js";import"./constants-Det-crLR.js";import"./keyboard-DjPTeb34.js";import"./os-CX2jsE2T.js";import"./router-ojPudCoe.js";import"./ts.worker-DkAHoi4g.js";import"./organization-Dk3JTuUx.js";import"./project-BQv_7rtt.js";import"./record-DPzM6a91.js";import"./tables-BMVW9iML.js";import"./string-BRV4TUDx.js";import"./organizationSwitcher-pCtulXBp.js";import"./folder-BrFYmaTS.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-Cy8WGmvB.js";import"./member-TYYGvoVs.js";import"./index-DJCu37sV.js";import"./index-2x_-08_Y.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-BjmHuGHe.js";import"./PhNotePencil.vue-CGLwBtc0.js";import"./PhSignOut.vue-XhGpAH-d.js";import"./index-BVluKOQL.js";import"./index--5YuzRe8.js";import"./PhPlus.vue-D3EOR9xq.js";import"./omniChatStore-z7SvOr9n.js";import"./contracts.generated-efRQDGYf.js";import"./runnerData-BTnVLbIe.js";import"./url-BfQ3Piw2.js";import"./colorHelpers-a5rBCCrE.js";import"./uuid-GqoJlV-e.js";import"./PhCopySimple.vue-D-EcVDEU.js";import"./index-rK-2K9Ta.js";import"./index-LZoAkFce.js";import"./ant-design-DaUV_Ap_.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="c00479a7-cd95-4039-8345-3f9be6ecbea2",t._sentryDebugIdIdentifier="sentry-dbid-c00479a7-cd95-4039-8345-3f9be6ecbea2")}catch{}})();const ct=g({__name:"Organization",setup(t){const o=_(),m=z(),p=r(()=>o.params.organizationId),e=r(()=>m.fetchedState?.organization),d=r(()=>e.value?{organizationId:e.value.id}:void 0),s=r(()=>e.value?.billingMetadata);return(I,C)=>{const u=v("RouterView");return i(),a(f,null,{navbar:n(()=>[c(l,{"use-cascader":!0,"cascader-props":d.value},null,8,["cascader-props"])]),content:n(()=>[c(b,null,{default:n(()=>[s.value?(i(),a(w,{key:0,"billing-metadata":s.value,"organization-id":p.value},null,8,["billing-metadata","organization-id"])):y("",!0),(i(),a(u,{key:p.value}))]),_:1})]),_:1})}}});export{ct as default};
//# sourceMappingURL=Organization-DS8YXQls.js.map
