import{C as p,_ as i}from"./View.vue_vue_type_script_setup_true_lang-Do7TbSX-.js";import{e as n,an as s,f as m,h as a,j as f}from"./jwt-decode.esm-pqcXkgNc.js";import"./router-ojPudCoe.js";import"./ts.worker-DkAHoi4g.js";import"./fetch-nKqeW1eP.js";import"./record-DPzM6a91.js";import"./SaveButton-Dnzd_IjP.js";import"./ExclamationCircleOutlined-BTcxMspb.js";import"./CrudView-CbIlDbzI.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-CLi_x9V2.js";import"./constants-Det-crLR.js";import"./url-BfQ3Piw2.js";import"./PhDotsThreeVertical.vue-D9bo5zY3.js";import"./index-BVluKOQL.js";import"./asyncComputed-CsbBiKJX.js";import"./omniChatStore-z7SvOr9n.js";import"./contracts.generated-efRQDGYf.js";import"./runnerData-BTnVLbIe.js";import"./colorHelpers-a5rBCCrE.js";import"./uuid-GqoJlV-e.js";import"./PhCopySimple.vue-D-EcVDEU.js";import"./PhPencil.vue-BBfDQL56.js";import"./useCodebaseEvents-BHUQjcta.js";import"./index-LZoAkFce.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="6fb30785-e85f-4394-8555-52a95ea52f66",o._sentryDebugIdIdentifier="sentry-dbid-6fb30785-e85f-4394-8555-52a95ea52f66")}catch{}})();const G=n({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,c)=>(a(),m(i,{"env-var-repository":f(e),mode:"console"},null,8,["env-var-repository"]))}});export{G as default};
//# sourceMappingURL=EnvVars-CrF7Y-7D.js.map
