import{P as g}from"./PlayerNavbar-dZdLlMAM.js";import{e as _,an as i,r as h,b,y,f as k,g as v,D as w,j as n,m as L,ab as C,ai as I,h as c,aO as N}from"./jwt-decode.esm-pqcXkgNc.js";import{u as D}from"./workspaceStore-Cf1MezzO.js";import"./userStore-DUZ9Imls.js";import"./metadata-_QrXhJic.js";import"./PhHouse.vue-DwDZLiSB.js";import"./PhMagnifyingGlass.vue-BVZlK68i.js";import"./PhWebhooksLogo.vue-Bjm6VNZ_.js";import"./LoadingOutlined-inK_SFIw.js";import"./PhSignOut.vue-XhGpAH-d.js";import"./index--5YuzRe8.js";import"./runnerData-BTnVLbIe.js";import"./url-BfQ3Piw2.js";import"./colorHelpers-a5rBCCrE.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="edf58229-ebee-4964-bbab-a76a98d6995c",o._sentryDebugIdIdentifier="sentry-dbid-edf58229-ebee-4964-bbab-a76a98d6995c")}catch{}})();const V={class:"main-container"},B={class:"content"},R=_({__name:"Main",setup(o){const e=I(),t=D(),d=i().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),y("div",V,[n(t).state.workspace?(c(),k(g,{key:0,"current-path":n(d),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",B,[L(f)])])}}}),H=N(R,[["__scopeId","data-v-f095bece"]]);export{H as default};
//# sourceMappingURL=Main-CT-9Y9xE.js.map
